@@ -43,202 +43,8 @@ from macapype.utils.misc import parse_key, list_input_files
 # -soft SPM or SPM_T1
 ###############################################################################
 def create_full_spm_subpipes(
-        params_template, params={}, name='full_spm_subpipes'):
-    """ Description: SPM based segmentation pipeline from T1w and T2w images
-    in template space
-
-    Processing steps:
-
-    - Data preparation (short, with betcrop or crop)
-    - debias using T1xT2BiasFieldCorrection (using mask is betcrop)
-    - registration to template file with IterREGBET
-    - SPM segmentation the old way (SPM8, not dartel based)
-
-    Params:
-
-    - short_data_preparation_pipe (see :class:`create_short_preparation_pipe \
-    <macapype.pipelines.prepare.create_short_preparation_pipe>`)
-    - debias (see :class:`T1xT2BiasFieldCorrection \
-    <macapype.nodes.correct_bias.T1xT2BiasFieldCorrection>`) - also available \
-    as :ref:`indiv_params <indiv_params>`
-    - reg (see :class:`IterREGBET <macapype.nodes.register.IterREGBET>`) - \
-    also available as :ref:`indiv_params <indiv_params>`
-    - old_segment_pipe (see :class:`create_old_segment_pipe \
-    <macapype.pipelines.segment.create_old_segment_pipe>`)
-    - nii_to_mesh_fs_pipe (see :class:`create_nii_to_mesh_fs_pipe \
-    <macapype.pipelines.surface.create_nii_to_mesh_fs_pipe>`)
-
-    Inputs:
-
-        inputnode:
-
-            list_T1:
-                T1 file names
-
-            list_T2:
-                T2 file names
-
-            indiv_params (opt):
-                dict with individuals parameters for some nodes
-
-
-        arguments:
-
-            params_template:
-                dict of template files containing brain_template and priors \
-            (list of template based segmented tissues)
-
-            params:
-                dictionary of node sub-parameters (from a json file)
-
-            name:
-                pipeline name (default = "full_spm_subpipes")
-
-    Outputs:
-
-            old_segment_pipe.thresh_gm.out_file:
-                segmented grey matter in template space
-
-            old_segment_pipe.thresh_wm.out_file:
-                segmented white matter in template space
-
-            old_segment_pipe.thresh_csf.out_file:
-                segmented csf in template space
-    """
-
-    print("Full pipeline name: ", name)
-
-    # Creating pipeline
-    seg_pipe = pe.Workflow(name=name)
-
-    # Creating input node
-    inputnode = pe.Node(
-        niu.IdentityInterface(fields=['list_T1', 'list_T2', 'indiv_params']),
-        name='inputnode'
-    )
-
-    # output node
-    outputnode = pe.Node(
-        niu.IdentityInterface(fields=['brain_mask', 'norm_T1',
-                                      'segmented_brain_mask']),
-        name='outputnode')
-
-    # preprocessing
-    if 'short_preparation_pipe' in params.keys():
-
-        data_preparation_pipe = create_short_preparation_pipe(
-            params=parse_key(params, "short_preparation_pipe"))
-    else:
-        print("Error, short_preparation_pipe was not \
-            found in params, skipping")
-        return seg_pipe
-
-    seg_pipe.connect(inputnode, 'list_T1',
-                     data_preparation_pipe, 'inputnode.list_T1')
-    seg_pipe.connect(inputnode, 'list_T2',
-                     data_preparation_pipe, 'inputnode.list_T2')
-    seg_pipe.connect(inputnode, 'indiv_params',
-                     data_preparation_pipe, 'inputnode.indiv_params')
-
-    # Bias correction of cropped images
-    debias = NodeParams(T1xT2BiasFieldCorrection(),
-                        params=parse_key(params, "debias"),
-                        name='debias')
-
-    seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T1',
-                     debias, 't1_file')
-    seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T2',
-                     debias, 't2_file')
-    seg_pipe.connect(inputnode, ('indiv_params', parse_key, "debias"),
-                     debias, 'indiv_params')
-
-    if 'bet_crop' in parse_key(params, "short_preparation_pipe"):
-        seg_pipe.connect(data_preparation_pipe, 'bet_crop.mask_file',
-                         debias, 'b')
-    else:
-        debias.inputs.bet = 1
-
-    seg_pipe.connect(debias, 'debiased_mask_file',
-                     outputnode, 'brain_mask')
-
-    # Iterative registration to the INIA19 template
-    reg = NodeParams(IterREGBET(),
-                     params=parse_key(params, "reg"),
-                     name='reg')
-
-    reg.inputs.refb_file = params_template["template_brain"]
-
-    seg_pipe.connect(debias, 't1_debiased_file', reg, 'inw_file')
-    seg_pipe.connect(debias, 't1_debiased_brain_file',
-                     reg, 'inb_file')
-
-    seg_pipe.connect(inputnode, ('indiv_params', parse_key, "reg"),
-                     reg, 'indiv_params')
-
-    seg_pipe.connect(reg, 'warp_file',
-                     outputnode, 'norm_T1')
-
-    # Compute brain mask using old_segment of SPM and postprocessing on
-    # tissues' masks
-    if "old_segment_pipe" in params.keys():
-
-        old_segment_pipe = create_old_segment_pipe(
-            params_template, params=parse_key(params, "old_segment_pipe"))
-
-        seg_pipe.connect(reg, 'warp_file',
-                         old_segment_pipe, 'inputnode.T1')
-
-        seg_pipe.connect(
-            inputnode, 'indiv_params',
-            old_segment_pipe, 'inputnode.indiv_params')
-
-    else:
-        return seg_pipe
-
-    # not mandatory
-    if "nii_to_mesh_fs_pipe" in params.keys():
-        nii_to_mesh_fs_pipe = create_nii_to_mesh_fs_pipe(
-            params=parse_key(params, "nii_to_mesh_fs_pipe"))
-
-        seg_pipe.connect(reg, 'warp_file',
-                         nii_to_mesh_fs_pipe, 'inputnode.reg_brain_file')
-
-        seg_pipe.connect(old_segment_pipe, 'outputnode.threshold_wm',
-                         nii_to_mesh_fs_pipe, 'inputnode.wm_mask_file')
-
-        seg_pipe.connect(inputnode, 'indiv_params',
-                         nii_to_mesh_fs_pipe, 'inputnode.indiv_params')
-
-    # not mandatory
-    if "mask_from_seg_pipe" in params.keys():
-        mask_from_seg_pipe = create_mask_from_seg_pipe(
-            params=parse_key(params, "mask_from_seg_pipe"))
-
-        seg_pipe.connect(old_segment_pipe, 'outputnode.threshold_csf',
-                         mask_from_seg_pipe, 'inputnode.mask_csf')
-
-        seg_pipe.connect(old_segment_pipe, 'outputnode.threshold_wm',
-                         mask_from_seg_pipe, 'inputnode.mask_wm')
-
-        seg_pipe.connect(old_segment_pipe, 'outputnode.threshold_gm',
-                         mask_from_seg_pipe, 'inputnode.mask_gm')
-
-        seg_pipe.connect(inputnode, 'indiv_params',
-                         mask_from_seg_pipe, 'inputnode.indiv_params')
-
-        seg_pipe.connect(mask_from_seg_pipe, 'merge_indexed_mask.indexed_mask',
-                         outputnode, 'segmented_brain_mask')
-
-    return seg_pipe
-
-
-###############################################################################
-# SPM based segmentation (from: Régis Trapeau)
-# -soft SPM_native or SPM_T1_native
-###############################################################################
-def create_full_native_spm_subpipes(
-        params_template, params={}, name='full_native_spm_subpipes',
-        pad=False):
+        params_template, params={}, name='full_spm_subpipes',
+        pad=False, space='template'):
 
     """ Description: SPM based segmentation pipeline from T1w and T2w images
     in template space
@@ -377,65 +183,101 @@ def create_full_native_spm_subpipes(
         seg_pipe.connect(debias, 'debiased_mask_file',
                          outputnode, "brain_mask")
 
-    if "native_iter_reg_pipe" in params.keys():
-        native_reg_pipe = create_native_iter_reg_pipe(
+    if space == "native":
+
+        native_iter_reg_pipe = create_native_iter_reg_pipe(
             params_template,
             params=parse_key(params, "native_iter_reg_pipe"))
 
         seg_pipe.connect(debias, 't1_debiased_brain_file',
-                         native_reg_pipe, 'inputnode.t1_debiased_brain_file')
+                         native_iter_reg_pipe,
+                         'inputnode.t1_debiased_brain_file')
 
         seg_pipe.connect(debias, 't1_debiased_file',
-                         native_reg_pipe, 'inputnode.t1_debiased_file')
+                         native_iter_reg_pipe, 'inputnode.t1_debiased_file')
 
         seg_pipe.connect(inputnode, 'indiv_params',
-                         native_reg_pipe, 'inputnode.indiv_params')
-    else:
-        return seg_pipe
+                         native_iter_reg_pipe, 'inputnode.indiv_params')
 
-    # Compute brain mask using old_segment of SPM and postprocessing on
-    # tissues' masks
-    if "native_old_segment_pipe" in params.keys():
+        # Compute brain mask using old_segment of SPM and postprocessing on
+        # tissues' masks
+        if "old_segment_pipe" in params.keys():
 
-        native_old_segment_pipe = create_native_old_segment_pipe(
-            params_template,
-            params=parse_key(params, "native_old_segment_pipe"))
+            old_segment_pipe = create_native_old_segment_pipe(
+                params_template,
+                params=parse_key(params, "old_segment_pipe"))
 
-        seg_pipe.connect(debias, 't1_debiased_file',
-                         native_old_segment_pipe, 'inputnode.T1')
+            seg_pipe.connect(debias, 't1_debiased_file',
+                             old_segment_pipe, 'inputnode.T1')
 
-        seg_pipe.connect(native_reg_pipe, 'register_csf_to_nat.out_file',
-                         native_old_segment_pipe, 'inputnode.native_csf')
+            seg_pipe.connect(native_iter_reg_pipe,
+                             'register_csf_to_nat.out_file',
+                             old_segment_pipe, 'inputnode.native_csf')
 
-        seg_pipe.connect(native_reg_pipe, 'register_wm_to_nat.out_file',
-                         native_old_segment_pipe, 'inputnode.native_wm')
+            seg_pipe.connect(native_iter_reg_pipe,
+                             'register_wm_to_nat.out_file',
+                             old_segment_pipe, 'inputnode.native_wm')
 
-        seg_pipe.connect(native_reg_pipe, 'register_gm_to_nat.out_file',
-                         native_old_segment_pipe, 'inputnode.native_gm')
+            seg_pipe.connect(native_iter_reg_pipe,
+                             'register_gm_to_nat.out_file',
+                             old_segment_pipe, 'inputnode.native_gm')
 
-        seg_pipe.connect(inputnode, 'indiv_params',
-                         native_old_segment_pipe, 'inputnode.indiv_params')
+            seg_pipe.connect(inputnode, 'indiv_params',
+                             old_segment_pipe, 'inputnode.indiv_params')
 
-    else:
-        return seg_pipe
+        else:
+            return seg_pipe
+
+    elif space == 'template':
+
+        # Iterative registration to the INIA19 template
+        reg = NodeParams(IterREGBET(),
+                         params=parse_key(params, "reg"),
+                         name='reg')
+
+        reg.inputs.refb_file = params_template["template_brain"]
+
+        seg_pipe.connect(debias, 't1_debiased_file', reg, 'inw_file')
+        seg_pipe.connect(debias, 't1_debiased_brain_file',
+                         reg, 'inb_file')
+
+        seg_pipe.connect(inputnode, ('indiv_params', parse_key, "reg"),
+                         reg, 'indiv_params')
+
+        # Compute brain mask using old_segment of SPM and postprocessing on
+        # tissues' masks
+        if "old_segment_pipe" in params.keys():
+
+            old_segment_pipe = create_old_segment_pipe(
+                params_template, params=parse_key(params, "old_segment_pipe"))
+
+            seg_pipe.connect(reg, 'warp_file',
+                             old_segment_pipe, 'inputnode.T1')
+
+            seg_pipe.connect(inputnode, 'indiv_params',
+                             old_segment_pipe, 'inputnode.indiv_params')
+
+        else:
+            return seg_pipe
 
     if "mask_from_seg_pipe" in params.keys():
+
         mask_from_seg_pipe = create_mask_from_seg_pipe(
             params=parse_key(params, "mask_from_seg_pipe"))
 
-        seg_pipe.connect(native_old_segment_pipe, 'outputnode.threshold_csf',
+        seg_pipe.connect(old_segment_pipe, 'outputnode.threshold_csf',
                          mask_from_seg_pipe, 'inputnode.mask_csf')
 
-        seg_pipe.connect(native_old_segment_pipe, 'outputnode.threshold_wm',
+        seg_pipe.connect(old_segment_pipe, 'outputnode.threshold_wm',
                          mask_from_seg_pipe, 'inputnode.mask_wm')
 
-        seg_pipe.connect(native_old_segment_pipe, 'outputnode.threshold_gm',
+        seg_pipe.connect(old_segment_pipe, 'outputnode.threshold_gm',
                          mask_from_seg_pipe, 'inputnode.mask_gm')
 
         seg_pipe.connect(inputnode, 'indiv_params',
                          mask_from_seg_pipe, 'inputnode.indiv_params')
 
-        if pad:
+        if pad and space == "native":
 
             print("Padding seg mask in native space")
 
@@ -465,6 +307,22 @@ def create_full_native_spm_subpipes(
                              'merge_indexed_mask.indexed_mask',
                              outputnode, 'segmented_brain_mask')
 
+    if space == 'template':
+
+        # not mandatory
+        if "nii_to_mesh_fs_pipe" in params.keys():
+            nii_to_mesh_fs_pipe = create_nii_to_mesh_fs_pipe(
+                params=parse_key(params, "nii_to_mesh_fs_pipe"))
+
+            seg_pipe.connect(reg, 'warp_file',
+                             nii_to_mesh_fs_pipe, 'inputnode.reg_brain_file')
+
+            seg_pipe.connect(old_segment_pipe, 'outputnode.threshold_wm',
+                             nii_to_mesh_fs_pipe, 'inputnode.wm_mask_file')
+
+            seg_pipe.connect(inputnode, 'indiv_params',
+                             nii_to_mesh_fs_pipe, 'inputnode.indiv_params')
+
     return seg_pipe
 
 
@@ -1335,7 +1193,7 @@ def create_brain_extraction_T1_pipe(params_template, params={},
     # brain extraction (with atlasbrex)
     extract_T1_pipe = create_extract_T1_pipe(
         params_template=params_template,
-        params=parse_key(params, "extract_T1_pipe"))
+        params=parse_key(params, "extract_pipe"))
 
     brain_extraction_pipe.connect(inputnode, "preproc_T1",
                                   extract_T1_pipe, "inputnode.restore_T1")
@@ -1504,8 +1362,7 @@ def create_brain_segment_from_mask_T1_template_pipe(
     # register NMT template, template mask and priors to subject T1
     register_NMT_pipe = create_register_NMT_pipe(
         params_template=params_template,
-        params=parse_key(params, "register_NMT_pipe"), NMT_version=NMT_version,
-        space="template")
+        params=parse_key(params, "register_NMT_pipe"), NMT_version=NMT_version)
 
     brain_segment_pipe.connect(
         restore_mask_T1, 'out_file',
@@ -1589,12 +1446,12 @@ def create_full_T1_ants_subpipes(params_template, params={},
         name='outputnode')
 
     # preprocessing (perform preparation pipe with only T1)
-    if 'short_preparation_T1_pipe' in params.keys():
+    if 'short_preparation_pipe' in params.keys():
         data_preparation_pipe = create_short_preparation_T1_pipe(
-            params=parse_key(params, "short_preparation_T1_pipe"))
+            params=parse_key(params, "short_preparation_pipe"))
 
     else:
-        print("Error, short_preparation_T1_pipe was not found in params, \
+        print("Error, short_preparation_pipe was not found in params, \
             skipping")
         return seg_pipe
 
@@ -1604,11 +1461,13 @@ def create_full_T1_ants_subpipes(params_template, params={},
                      data_preparation_pipe, 'inputnode.indiv_params')
 
     # full extract brain pipeline (correct_bias, denoising, extract brain)
-    if "brain_extraction_T1_pipe" not in params.keys():
+    if "brain_extraction_pipe" not in params.keys():
+        print("Error, brain_extraction_pipe was not found in params, \
+            skipping")
         return seg_pipe
 
     brain_extraction_pipe = create_brain_extraction_T1_pipe(
-        params=parse_key(params, "brain_extraction_T1_pipe"),
+        params=parse_key(params, "brain_extraction_pipe"),
         params_template=params_template)
 
     seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T1',
@@ -1621,14 +1480,16 @@ def create_full_T1_ants_subpipes(params_template, params={},
                      outputnode, "brain_mask")
 
     # full_segment (restarting from the avg_align files)
-    if "brain_segment_T1_pipe" not in params.keys():
+    if "brain_segment_pipe" not in params.keys():
+        print("Error, brain_segment_pipe was not found in params, \
+            skipping")
         return seg_pipe
 
     if space == "native":
 
         brain_segment_pipe = create_brain_segment_from_mask_T1_pipe(
             params_template=params_template,
-            params=parse_key(params, "brain_segment_T1_pipe"))
+            params=parse_key(params, "brain_segment_pipe"))
 
         seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T1',
                          brain_segment_pipe, 'inputnode.preproc_T1')
@@ -1642,7 +1503,7 @@ def create_full_T1_ants_subpipes(params_template, params={},
 
         brain_segment_pipe = create_brain_segment_from_mask_T1_template_pipe(
             params_template=params_template,
-            params=parse_key(params, "brain_segment_T1_template_pipe"))
+            params=parse_key(params, "brain_segment_pipe"))
 
         seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T1',
                          brain_segment_pipe, 'inputnode.preproc_T1')
